multi_bloc_builder library

Classes

MultiBlocBuilder
Signature for the builder function which takes the BuildContext and current ListBlocState and is responsible for returning a widget which is to be rendered. This is analogous to the builder function in BlocBuilder.
MultiBlocConsumer
A widget that combines the functionality of MultiBlocBuilder and a listener.

Extensions

ListMultiBlocStateExtension on ListBlocState
Extension on ListMultiBlocState to get the first state of type T.

Typedefs

ListBloc = List<BlocBase>
List BlocBase for MultiBlocBuilder and MultiBlocConsumer
ListBlocState = List
State of ListBloc
MultiBlocBuilderCallback = Widget Function(BuildContext, ListBlocState)
MultiBlocBuilderCallback function for builder child in MultiBlocBuilder
MultiBlocBuildWhenCallback = bool Function(ListBlocState, ListBlocState)
MultiBlocListenWhenCallback function for check State Bloc for rebuild or rebuild child in MultiBlocConsumer
MultiBlocListenerCallback = void Function(BuildContext, ListBlocState)
MultiBlocListenerCallback function for listener in MultiBlocConsumer
MultiBlocListenWhenCallback = bool Function(ListBlocState, ListBlocState)
MultiBlocListenWhenCallback function for check State Bloc for listen or rebuild child in MultiBlocConsumer